aboutsummaryrefslogtreecommitdiff
path: root/include/Process.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'include/Process.hpp')
-rw-r--r--include/Process.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/Process.hpp b/include/Process.hpp
index 125a880..731062e 100644
--- a/include/Process.hpp
+++ b/include/Process.hpp
@@ -12,8 +12,8 @@ namespace gsr {
// Arguments ending with NULL
bool exec_program_daemonized(const char **args);
- // Arguments ending with NULL
- pid_t exec_program(const char **args);
+ // Arguments ending with NULL. |read_fd| can be NULL
+ pid_t exec_program(const char **args, int *read_fd);
// |output_buffer| should be at least PATH_MAX in size
bool read_cmdline_arg0(const char *filepath, char *output_buffer);
} \ No newline at end of file